@@ -1,9 +1,9 @@
 /*
- *  $Id: msgbox.c,v 1.88 2020/03/27 20:38:45 tom Exp $
+ *  $Id: msgbox.c,v 1.91 2025/01/09 22:33:20 tom Exp $
  *
  *  msgbox.c -- implements the message box and info box
  *
- *  Copyright 2000-2019,2020	Thomas E. Dickey
+ *  Copyright 2000-2022,2025	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -24,7 +24,7 @@
  *	Savio Lam (lam836@cs.cuhk.hk)
  */
 
-#include <dialog.h>
+#include <dlg_internals.h>
 #include <dlg_keys.h>
 
 /*
@@ -49,7 +49,7 @@ dialog_msgbox(const char *title, const char *cprompt, int height, int width,
     int button;
     int key, fkey;
     int result = DLG_EXIT_UNKNOWN;
-    WINDOW *dialog = 0;
+    WINDOW *dialog = NULL;
     char *prompt;
     const char **buttons = dlg_ok_label();
     int offset = 0;
@@ -161,6 +161,9 @@ dialog_msgbox(const char *title, const char *cprompt, int height, int width,
 				     FALSE, width);
 		    break;
 		case DLGK_ENTER:
+		    result = dlg_enter_buttoncode(button);
+		    break;
+		case DLGK_LEAVE:
 		    result = dlg_ok_buttoncode(button);
 		    break;
 		default:
