@@ -1,9 +1,9 @@
 /*
- *  $Id: version.c,v 1.6 2010/01/15 23:34:46 tom Exp $
+ *  $Id: version.c,v 1.7 2022/04/03 22:38:16 tom Exp $
  *
  *  version.c -- dialog's version string
  *
- *  Copyright 2005-2006,2010	Thomas E. Dickey
+ *  Copyright 2005-2010,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -20,7 +20,7 @@
  *	51 Franklin St., Fifth Floor
  *	Boston, MA 02110, USA.
  */
-#include <dialog.h>
+#include <dlg_internals.h>
 
 #define quoted(a)	#a
 #define concat(a,b)	a "-" quoted(b)
